@@ -12,6 +12,7 @@ from selenium.webdriver.common.by import By
 from selenium.webdriver.support.ui import WebDriverWait
 from selenium.webdriver.support import expected_conditions as EC
 from typing import Dict, List
+import pyotp
 
 
 def get_authorization_url():
@@ -70,6 +71,7 @@ class MasterTrust(Broker):
         product="MIS",
         token_file="token.tok",
     ):
+        print("into here")
         self.filter = dict_filter
         self._client_id = client_id
         self._password = password
@@ -187,7 +189,9 @@ class MasterTrust(Broker):
         WebDriverWait(driver, 45).until(
             EC.presence_of_element_located((By.CLASS_NAME, "btn-container"))
         )
-        driver.find_element_by_xpath('//input[@type="password"]').send_keys(self._pin)
+        driver.find_element_by_xpath('//input[@type="password"]').send_keys(
+            pyotp.TOTP(self._pin).now()
+        )
         driver.find_element_by_xpath('//button[@type="submit"]').click()
         time.sleep(2)
         current_url = driver.current_url
